Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(243)

Unified Diff: chrome/browser/ui/browser_command_controller.h

Issue 2689383002: Commands should have consistent behaviors across different modes
Patch Set: Resolve review comments Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/browser_command_controller.h
diff --git a/chrome/browser/ui/browser_command_controller.h b/chrome/browser/ui/browser_command_controller.h
index 7c1370ddec3278f407e639f60e1ed472313c7b88..2e09d7142633571587c26124fdebede1d37f71af 100644
--- a/chrome/browser/ui/browser_command_controller.h
+++ b/chrome/browser/ui/browser_command_controller.h
@@ -70,11 +70,12 @@ class BrowserCommandController : public CommandUpdaterDelegate,
// Updates the open-file state.
static void UpdateOpenFileState(CommandUpdater* command_updater);
// Update commands whose state depends on incognito mode availability and that
// only depend on the profile.
static void UpdateSharedCommandsForIncognitoAvailability(
CommandUpdater* command_updater,
- Profile* profile);
+ Profile* profile,
+ bool is_fullscreen);
private:
class InterstitialObserver;
@@ -70,11 +70,12 @@ class BrowserCommandController : public CommandUpdaterDelegate,
// Updates the open-file state.
static void UpdateOpenFileState(CommandUpdater* command_updater);
- // Update commands whose state depends on incognito mode availability and that
- // only depend on the profile.
+ // Update commands whose state depends on incognito mode availability and
+ // fullscreen state.
static void UpdateSharedCommandsForIncognitoAvailability(
CommandUpdater* command_updater,

Powered by Google App Engine
This is Rietveld 408576698